@@ -13,10 +13,9 @@ fi
 SRC_DIR=$(cd $(dirname $0) && pwd)
 
 THEME_NAME=Qogir
-THEME_VARIANTS=('' '-manjaro' '-ubuntu')
-WIN_VARIANTS=('' '-win')
-COLOR_VARIANTS=('' '-light' '-dark')
-LOGO_NAME=''
+THEME_VARIANTS=('' '-Manjaro' '-Ubuntu')
+COLOR_VARIANTS=('' '-Light' '-Dark')
+ICON_NAME=''
 
 image=''
 window=''
@@ -27,16 +26,18 @@ theme_color='default'
 SASSC_OPT="-M -t expanded"
 
 if [[ "$(command -v gnome-shell)" ]]; then
+  gnome-shell --version
   SHELL_VERSION="$(gnome-shell --version | cut -d ' ' -f 3 | cut -d . -f -1)"
-  echo "Your gnome-shell version is '$(gnome-shell --version)'"
-  if [[ "${SHELL_VERSION:-}" -ge "40" ]]; then
-    GS_VERSION="new"
+  if [[ "${SHELL_VERSION:-}" -ge "42" ]]; then
+    GS_VERSION="42-0"
+  elif [[ "${SHELL_VERSION:-}" -ge "40" ]]; then
+    GS_VERSION="40-0"
   else
-    GS_VERSION="old"
+    GS_VERSION="3-32"
   fi
   else
     echo "'gnome-shell' not found, using styles for last gnome-shell version available."
-    GS_VERSION="new"
+    GS_VERSION="42-0"
 fi
 
 usage() {
@@ -52,16 +53,19 @@ OPTIONS:
 
   -c, --color VARIANT     Specify theme color variant(s) [standard|light|dark] (Default: All variants)
 
-  -l, --logo VARIANT      Specify logo icon on nautilus [default|manjaro|ubuntu|fedora|debian|arch|gnome|budgie|popos] (Default: mountain icon)
+  -i, --icon VARIANT      Specify logo icon on nautilus [default|manjaro|ubuntu|fedora|debian|arch|gnome|budgie|popos|gentoo|void|zorin|mxlinux|opensuse] (Default: mountain icon)
 
   -g, --gdm               Install GDM theme, this option need root user authority! please run this with sudo
 
-  -r, --revert            revert GDM theme, this option need root user authority! please run this with sudo
+  -l, --libadwaita        Install link to gtk4 config for theming libadwaita
+
+  -r, --remove,
+  -u, --uninstall         Uninstall/Remove installed themes
 
   --tweaks                Specify versions for tweaks [image|square|round] (options can mix use)
-                          1. image:    Install with a background image on (Nautilus/Nemo)
-                          2. square:   Install square window button like Windows 10
-                          3. round:    Install rounded window and popup/menu version
+                          1. image:      Install with a background image on (Nautilus/Nemo)
+                          2. square:     Install square window button like Windows 10
+                          3. round:      Install rounded window and popup/menu version
 
   -h, --help              Show help
 EOF
@@ -72,10 +76,10 @@ install() {
   local name=${2}
   local theme=${3}
   local color=${4}
-  local logo=${5}
+  local icon=${5}
 
-  [[ ${color} == '-dark' ]] && local ELSE_DARK=${color}
-  [[ ${color} == '-light' ]] && local ELSE_LIGHT=${color}
+  [[ ${color} == '-Dark' ]] && local ELSE_DARK=${color}
+  [[ ${color} == '-Light' ]] && local ELSE_LIGHT=${color}
 
   local THEME_DIR=${dest}/${name}${theme}${color}
 
@@ -113,11 +117,11 @@ install() {
   mkdir -p                                                                           ${THEME_DIR}/gtk-3.0
   cp -r ${SRC_DIR}/src/gtk/assets/assets${theme}                                     ${THEME_DIR}/gtk-3.0/assets
 
-  if [[ -f ${SRC_DIR}/src/gtk/assets/logos/logo-${logo}.svg ]] ; then
-    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo-${logo}.svg                           ${THEME_DIR}/gtk-3.0/assets/logo.svg
-    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo@2-${logo}.svg                         ${THEME_DIR}/gtk-3.0/assets/logo@2.svg
+  if [[ -f ${SRC_DIR}/src/gtk/assets/logos/logo-${icon}.svg ]] ; then
+    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo-${icon}.svg                           ${THEME_DIR}/gtk-3.0/assets/logo.svg
+    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo@2-${icon}.svg                         ${THEME_DIR}/gtk-3.0/assets/logo@2.svg
   else
-    echo "${logo} icon not supported, default icon will install..."
+    echo "${icon} icon not supported, default icon will install..."
     cp -r ${SRC_DIR}/src/gtk/assets/logos/logo-.svg                                  ${THEME_DIR}/gtk-3.0/assets/logo.svg
     cp -r ${SRC_DIR}/src/gtk/assets/logos/logo@2-.svg                                ${THEME_DIR}/gtk-3.0/assets/logo@2.svg
   fi
@@ -126,16 +130,10 @@ install() {
 
   if [[ "$tweaks" == 'true' ]]; then
     sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-3.0/gtk${color}.scss                   ${THEME_DIR}/gtk-3.0/gtk.css
+    sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-3.0/gtk-Dark.scss                      ${THEME_DIR}/gtk-3.0/gtk-dark.css
   else
     cp -r ${SRC_DIR}/src/gtk/theme-3.0/gtk${color}.css                               ${THEME_DIR}/gtk-3.0/gtk.css
-  fi
-
-  if [[ ${color} != '-dark' ]]; then
-    if [[ "$tweaks" == 'true' ]]; then
-      sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-3.0/gtk-dark.scss                    ${THEME_DIR}/gtk-3.0/gtk-dark.css
-    else
-      cp -r ${SRC_DIR}/src/gtk/theme-3.0/gtk-dark.css                                ${THEME_DIR}/gtk-3.0/gtk-dark.css
-    fi
+    cp -r ${SRC_DIR}/src/gtk/theme-3.0/gtk-Dark.css                                  ${THEME_DIR}/gtk-3.0/gtk-dark.css
   fi
 
   cp -r ${SRC_DIR}/src/gtk/assets/thumbnail${theme}${ELSE_DARK}.png                  ${THEME_DIR}/gtk-3.0/thumbnail.png
@@ -144,11 +142,11 @@ install() {
   mkdir -p                                                                           ${THEME_DIR}/gtk-4.0
   cp -r ${SRC_DIR}/src/gtk/assets/assets${theme}                                     ${THEME_DIR}/gtk-4.0/assets
 
-  if [[ -f ${SRC_DIR}/src/gtk/assets/logos/logo-${logo}.svg ]] ; then
-    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo-${logo}.svg                           ${THEME_DIR}/gtk-4.0/assets/logo.svg
-    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo@2-${logo}.svg                         ${THEME_DIR}/gtk-4.0/assets/logo@2.svg
+  if [[ -f ${SRC_DIR}/src/gtk/assets/logos/logo-${icon}.svg ]] ; then
+    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo-${icon}.svg                           ${THEME_DIR}/gtk-4.0/assets/logo.svg
+    cp -r ${SRC_DIR}/src/gtk/assets/logos/logo@2-${icon}.svg                         ${THEME_DIR}/gtk-4.0/assets/logo@2.svg
   else
-    echo "${logo} icon not supported, default icon will install..."
+    echo "${icon} icon not supported, default icon will install..."
     cp -r ${SRC_DIR}/src/gtk/assets/logos/logo-.svg                                  ${THEME_DIR}/gtk-4.0/assets/logo.svg
     cp -r ${SRC_DIR}/src/gtk/assets/logos/logo@2-.svg                                ${THEME_DIR}/gtk-4.0/assets/logo@2.svg
   fi
@@ -157,48 +155,35 @@ install() {
 
   if [[ "$tweaks" == 'true' ]]; then
     sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-4.0/gtk${color}.scss                   ${THEME_DIR}/gtk-4.0/gtk.css
+    sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-4.0/gtk-Dark.scss                      ${THEME_DIR}/gtk-4.0/gtk-dark.css
   else
     cp -r ${SRC_DIR}/src/gtk/theme-4.0/gtk${color}.css                               ${THEME_DIR}/gtk-4.0/gtk.css
-  fi
-
-  if [[ ${color} != '-dark' ]]; then
-    if [[ "$tweaks" == 'true' ]]; then
-      sassc $SASSC_OPT ${SRC_DIR}/src/gtk/theme-4.0/gtk-dark.scss                    ${THEME_DIR}/gtk-4.0/gtk-dark.css
-    else
-      cp -r ${SRC_DIR}/src/gtk/theme-4.0/gtk-dark.css                                ${THEME_DIR}/gtk-4.0/gtk-dark.css
-    fi
+    cp -r ${SRC_DIR}/src/gtk/theme-4.0/gtk-Dark.css                                  ${THEME_DIR}/gtk-4.0/gtk-dark.css
   fi
 
   cp -r ${SRC_DIR}/src/gtk/assets/thumbnail${theme}${ELSE_DARK}.png                  ${THEME_DIR}/gtk-4.0/thumbnail.png
 
- # GNOME SHELL
+  # GNOME SHELL
   mkdir -p                                                                           ${THEME_DIR}/gnome-shell
   cp -r ${SRC_DIR}/src/gnome-shell/common-assets                                     ${THEME_DIR}/gnome-shell/assets
   cp -r ${SRC_DIR}/src/gnome-shell/assets${theme}/{background.jpg,calendar-today.svg} ${THEME_DIR}/gnome-shell/assets
   cp -r ${SRC_DIR}/src/gnome-shell/assets${theme}/assets${ELSE_DARK}/*.svg           ${THEME_DIR}/gnome-shell/assets
 
-  if [[ -f ${SRC_DIR}/src/gnome-shell/logos/logo-${logo}.svg ]] ; then
-    cp -r ${SRC_DIR}/src/gnome-shell/logos/logo-${logo}.svg                          ${THEME_DIR}/gnome-shell/assets/activities.svg
+  if [[ -f ${SRC_DIR}/src/gnome-shell/logos/logo-${icon}.svg ]] ; then
+    cp -r ${SRC_DIR}/src/gnome-shell/logos/logo-${icon}.svg                          ${THEME_DIR}/gnome-shell/assets/activities.svg
   else
-    echo "${logo} icon not supported, Qogir icon will install..."
+    echo "${icon} icon not supported, Qogir icon will install..."
     cp -r ${SRC_DIR}/src/gnome-shell/logos/logo-qogir.svg                            ${THEME_DIR}/gnome-shell/assets/activities.svg
   fi
 
   cp -r ${SRC_DIR}/src/gnome-shell/icons                                             ${THEME_DIR}/gnome-shell
   cp -r ${SRC_DIR}/src/gnome-shell/pad-osd.css                                       ${THEME_DIR}/gnome-shell
 
-  if [[ "${GS_VERSION:-}" == 'new' ]]; then
-    if [[ "$tweaks" == 'true' ]]; then
-      sassc $SASSC_OPT ${SRC_DIR}/src/gnome-shell/theme-40-0/gnome-shell${ELSE_DARK}.scss ${THEME_DIR}/gnome-shell/gnome-shell.css
-    else
-      cp -r ${SRC_DIR}/src/gnome-shell/theme-40-0/gnome-shell${ELSE_DARK}.css        ${THEME_DIR}/gnome-shell/gnome-shell.css
-    fi
+
+  if [[ "$tweaks" == 'true' ]]; then
+    sassc $SASSC_OPT ${SRC_DIR}/src/gnome-shell/theme-${GS_VERSION}/gnome-shell${ELSE_DARK}.scss ${THEME_DIR}/gnome-shell/gnome-shell.css
   else
-    if [[ "$tweaks" == 'true' ]]; then
-      sassc $SASSC_OPT ${SRC_DIR}/src/gnome-shell/theme-3-32/gnome-shell${ELSE_DARK}.scss ${THEME_DIR}/gnome-shell/gnome-shell.css
-    else
-      cp -r ${SRC_DIR}/src/gnome-shell/theme-3-32/gnome-shell${ELSE_DARK}.css        ${THEME_DIR}/gnome-shell/gnome-shell.css
-    fi
+    cp -r ${SRC_DIR}/src/gnome-shell/theme-${GS_VERSION}/gnome-shell${ELSE_DARK}.css ${THEME_DIR}/gnome-shell/gnome-shell.css
   fi
 
   cd ${THEME_DIR}/gnome-shell
@@ -222,14 +207,14 @@ install() {
   mkdir -p                                                                           ${THEME_DIR}/metacity-1
 
   if [[ "$window" == 'round' ]]; then
-    cp -r ${SRC_DIR}/src/metacity-1/assets-round                                     ${THEME_DIR}/metacity-1/assets
-    cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3-round.xml                       ${THEME_DIR}/metacity-1/metacity-theme-3.xml
-    cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}-round.xml          ${THEME_DIR}/metacity-1/metacity-theme-1.xml
+    cp -r ${SRC_DIR}/src/metacity-1/assets-Round                                     ${THEME_DIR}/metacity-1/assets
+    cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3-Round.xml                       ${THEME_DIR}/metacity-1/metacity-theme-3.xml
+    cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}-Round.xml          ${THEME_DIR}/metacity-1/metacity-theme-1.xml
   else
     if [[ "$square" == 'true' ]]; then
-      cp -r ${SRC_DIR}/src/metacity-1/assets${ELSE_LIGHT}-win/*.png                  ${THEME_DIR}/metacity-1
-      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3-win.xml                       ${THEME_DIR}/metacity-1/metacity-theme-3.xml
-      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}-win.xml          ${THEME_DIR}/metacity-1/metacity-theme-1.xml
+      cp -r ${SRC_DIR}/src/metacity-1/assets${ELSE_LIGHT}-Win/*.png                  ${THEME_DIR}/metacity-1
+      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3-Win.xml                       ${THEME_DIR}/metacity-1/metacity-theme-3.xml
+      cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-1${ELSE_LIGHT}-Win.xml          ${THEME_DIR}/metacity-1/metacity-theme-1.xml
     else
       cp -r ${SRC_DIR}/src/metacity-1/assets${ELSE_LIGHT}/*.png                      ${THEME_DIR}/metacity-1
       cp -r ${SRC_DIR}/src/metacity-1/metacity-theme-3.xml                           ${THEME_DIR}/metacity-1/metacity-theme-3.xml
@@ -241,94 +226,197 @@ install() {
   cd ${THEME_DIR}/metacity-1
   ln -s metacity-theme-1.xml metacity-theme-2.xml
 
-  # XFWM4
-  mkdir -p                                                                           ${THEME_DIR}/xfwm4
-
-  if [[ "$square" == 'true' ]]; then
-    cp -r ${SRC_DIR}/src/xfwm4/themerc-win${ELSE_LIGHT}                              ${THEME_DIR}/xfwm4/themerc
-    cp -r ${SRC_DIR}/src/xfwm4/assets-win${ELSE_LIGHT}/*.png                         ${THEME_DIR}/xfwm4
-  else
-    cp -r ${SRC_DIR}/src/xfwm4/themerc${ELSE_LIGHT}                                  ${THEME_DIR}/xfwm4/themerc
-    cp -r ${SRC_DIR}/src/xfwm4/assets${ELSE_LIGHT}/*.png                             ${THEME_DIR}/xfwm4
-  fi
-
   # OTHER
   cp -r ${SRC_DIR}/src/plank                                                         ${THEME_DIR}
   cp -r ${SRC_DIR}/src/unity                                                         ${THEME_DIR}
   cp -r ${SRC_DIR}/src/xfce-notify-4.0                                               ${THEME_DIR}
 }
 
-# Backup and install files related to GDM theme
+install_xfwm() {
+  local dest=${1}
+  local name=${2}
+  local color=${3}
+  local screen=${4}
 
-GS_THEME_FILE="/usr/share/gnome-shell/gnome-shell-theme.gresource"
-SHELL_THEME_FOLDER="/usr/share/gnome-shell/theme"
-UBUNTU_THEME_FILE="/usr/share/gnome-shell/theme/Yaru/gnome-shell-theme.gresource"
-POP_OS_THEME_FILE="/usr/share/gnome-shell/theme/Pop/gnome-shell-theme.gresource"
-ZORIN_THEME_FILE="/usr/share/gnome-shell/theme/ZorinBlue-Light/gnome-shell-theme.gresource"
+  [[ ${color} == '-Dark' ]] && local ELSE_DARK=${color}
+  [[ ${color} == '-Light' ]] && local ELSE_LIGHT=${color}
 
-install_gdm() {
-  local GDM_THEME_DIR="${1}/${2}${3}${4}"
+  local THEME_DIR=${dest}/${name}${color}${screen}
 
-  if [[ -f "$GS_THEME_FILE" ]] && command -v glib-compile-resources >/dev/null ; then
-    echo "Installing '$GS_THEME_FILE'..."
-    cp -an "$GS_THEME_FILE" "$GS_THEME_FILE.bak"
-    glib-compile-resources \
-      --sourcedir="$GDM_THEME_DIR/gnome-shell" \
-      --target="$GS_THEME_FILE" \
-      "${SRC_DIR}/src/gnome-shell/gnome-shell-theme.gresource.xml"
-  fi
+  [[ ${screen} != '' && -d ${THEME_DIR} ]] && rm -rf ${THEME_DIR}
 
-  if [[ -f "$UBUNTU_THEME_FILE" ]]; then
-    echo "Installing '$UBUNTU_THEME_FILE'..."
-    cp -an "$UBUNTU_THEME_FILE" "$UBUNTU_THEME_FILE.bak"
-    cp -rf "$GS_THEME_FILE" "$UBUNTU_THEME_FILE"
-  fi
+  # XFWM4
+  mkdir -p                                                                           ${THEME_DIR}/xfwm4
 
-  if [[ -f "$POP_OS_THEME_FILE" ]]; then
-    echo "Installing '$POP_OS_THEME_FILE'..."
-    cp -an "$POP_OS_THEME_FILE" "$POP_OS_THEME_FILE.bak"
-    cp -rf "$GS_THEME_FILE" "$POP_OS_THEME_FILE"
-  fi
-
-  if [[ -f "$ZORIN_THEME_FILE" ]]; then
-    echo "Installing '$ZORIN_THEME_FILE'..."
-    cp -an "$ZORIN_THEME_FILE" "$ZORIN_THEME_FILE.bak"
-    cp -rf "$GS_THEME_FILE" "$ZORIN_THEME_FILE"
+  if [[ "$square" == 'true' ]]; then
+    cp -r ${SRC_DIR}/src/xfwm4/themerc-Win${ELSE_LIGHT}                              ${THEME_DIR}/xfwm4/themerc
+    cp -r ${SRC_DIR}/src/xfwm4/assets-Win${ELSE_LIGHT}${screen}/*.png                ${THEME_DIR}/xfwm4
+  else
+    cp -r ${SRC_DIR}/src/xfwm4/themerc${ELSE_LIGHT}                                  ${THEME_DIR}/xfwm4/themerc
+    cp -r ${SRC_DIR}/src/xfwm4/assets${ELSE_LIGHT}${screen}/*.png                    ${THEME_DIR}/xfwm4
   fi
 }
 
-revert_gdm() {
-  if [[ -f "$GS_THEME_FILE.bak" ]]; then
-    echo "reverting '$GS_THEME_FILE'..."
-    rm -rf "$GS_THEME_FILE"
-    mv "$GS_THEME_FILE.bak" "$GS_THEME_FILE"
+uninstall() {
+  local dest=${1}
+  local name=${2}
+  local theme=${3}
+  local color=${4}
+  local screen=${5}
+
+  local THEME_DIR=${dest}/${name}${theme}${color}${screen}
+
+  [[ -d "$THEME_DIR" ]] && rm -rf "$THEME_DIR" && echo -e "Uninstalling "$THEME_DIR" ..."
+}
+
+# GDM Theme
+
+check_exist() {
+  [[ -f "${1}" || -f "${1}.bak" ]]
+}
+
+restore_file() {
+  if [[ -f "${1}.bak" || -d "${1}.bak" ]]; then
+    rm -rf "${1}"; mv "${1}"{".bak",""}
+  fi
+}
+
+backup_file() {
+  if [[ -f "${1}" || -d "${1}" ]]; then
+    mv -n "${1}"{"",".bak"}
+  fi
+}
+
+install_gdm_deps() {
+  if ! has_command glib-compile-resources; then
+    echo -e "\n'glib2.0' are required for theme installation."
+
+    if has_command zypper; then
+      sudo zypper in -y glib2-devel
+    elif has_command swupd; then
+      sudo swupd bundle-add libglib
+    elif has_command apt; then
+      sudo apt install libglib2.0-dev-bin
+    elif has_command dnf; then
+      sudo dnf install -y glib2-devel
+    elif has_command yum; then
+      sudo yum install -y glib2-devel
+    elif has_command pacman; then
+      sudo pacman -Syyu --noconfirm --needed glib2
+    elif has_command xbps-install; then
+      sudo xbps-install -Sy glib-devel
+    elif has_command eopkg; then
+      sudo eopkg -y install glib2
+    else
+      echo -e "\nWARNING: We're sorry, your distro isn't officially supported yet.\n"
+    fi
+  fi
+}
+
+GS_THEME_DIR="/usr/share/gnome-shell/theme"
+COMMON_CSS_FILE="/usr/share/gnome-shell/theme/gnome-shell.css"
+UBUNTU_CSS_FILE="/usr/share/gnome-shell/theme/ubuntu.css"
+ZORIN_CSS_FILE="/usr/share/gnome-shell/theme/zorin.css"
+ETC_CSS_FILE="/etc/alternatives/gdm3.css"
+ETC_GR_FILE="/etc/alternatives/gdm3-theme.gresource"
+YARU_GR_FILE="/usr/share/gnome-shell/theme/Yaru/gnome-shell-theme.gresource"
+POP_OS_GR_FILE="/usr/share/gnome-shell/theme/Pop/gnome-shell-theme.gresource"
+ZORIN_GR_FILE="/usr/share/gnome-shell/theme/ZorinBlue-Light/gnome-shell-theme.gresource"
+MISC_GR_FILE="/usr/share/gnome-shell/gnome-shell-theme.gresource"
+GS_GR_XML_FILE="${SRC_DIR}/src/gnome-shell/gnome-shell-theme.gresource.xml"
+
+install_gdm() {
+  local name="${1}"
+  local theme="${2}"
+  local gcolor="${3}"
+  local icon="${4}"
+  local TARGET=
+
+  [[ "${gcolor}" == '-Light' ]] && local ELSE_LIGHT="${gcolor}"
+  [[ "${gcolor}" == '-Dark' ]] && local ELSE_DARK="${gcolor}"
+
+  local THEME_TEMP="/tmp/${1}${2}${3}"
+
+  theme_tweaks && install_gdm_deps && install_theme_color
+
+  echo -e "\nInstall ${1}${2}${3} GDM Theme..."
+
+  rm -rf "${THEME_TEMP}"
+  mkdir -p                                                                                  "${THEME_TEMP}/gnome-shell"
+  cp -r "${SRC_DIR}/src/gnome-shell/common-assets"                                          "${THEME_TEMP}/gnome-shell/assets"
+  cp -r "${SRC_DIR}/src/gnome-shell/assets${theme}/"{background.jpg,calendar-today.svg}     "${THEME_TEMP}/gnome-shell/assets"
+  cp -r "${SRC_DIR}/src/gnome-shell/assets${theme}/assets${ELSE_DARK}/"*.svg                "${THEME_TEMP}/gnome-shell/assets"
+  mv "${THEME_TEMP}/gnome-shell/assets/"{process-working.svg,no-events.svg,no-notifications.svg} "${THEME_TEMP}/gnome-shell"
+
+  if [[ -f "${SRC_DIR}/src/gnome-shell/logos/logo-${icon}.svg" ]] ; then
+    cp -r "${SRC_DIR}/src/gnome-shell/logos/logo-${icon}.svg"                               "${THEME_TEMP}/gnome-shell/assets/activities.svg"
+  else
+    echo "${icon} icon not supported, Qogir icon will install..."
+    cp -r "${SRC_DIR}/src/gnome-shell/logos/logo-qogir.svg"                                 "${THEME_TEMP}/gnome-shell/assets/activities.svg"
   fi
 
-  if [[ -f "$UBUNTU_THEME_FILE.bak" ]]; then
-    echo "reverting '$UBUNTU_THEME_FILE'..."
-    rm -rf "$UBUNTU_THEME_FILE"
-    mv "$UBUNTU_THEME_FILE.bak" "$UBUNTU_THEME_FILE"
+  cp -r "${SRC_DIR}/src/gnome-shell/icons"                                                  "${THEME_TEMP}/gnome-shell"
+  cp -r "${SRC_DIR}/src/gnome-shell/pad-osd.css"                                            "${THEME_TEMP}/gnome-shell"
+
+  if [[ "$tweaks" == 'true' ]]; then
+    sassc $SASSC_OPT "${SRC_DIR}/src/gnome-shell/theme-${GS_VERSION}/gnome-shell${ELSE_DARK}.scss" "${THEME_TEMP}/gnome-shell/gnome-shell.css"
+  else
+    cp -r "${SRC_DIR}/src/gnome-shell/theme-${GS_VERSION}/gnome-shell${ELSE_DARK}.css" "${THEME_TEMP}/gnome-shell/gnome-shell.css"
   fi
 
-  if [[ -f "$POP_OS_THEME_FILE.bak" ]]; then
-    echo "reverting '$POP_OS_THEME_FILE'..."
-    rm -rf "$POP_OS_THEME_FILE"
-    mv "$POP_OS_THEME_FILE.bak" "$POP_OS_THEME_FILE"
-  fi
+  if check_exist "${COMMON_CSS_FILE}"; then # CSS-based theme
+    if check_exist "${UBUNTU_CSS_FILE}"; then
+      TARGET="${UBUNTU_CSS_FILE}"
+    elif check_exist "${ZORIN_CSS_FILE}"; then
+      TARGET="${ZORIN_CSS_FILE}"
+    fi
 
-  if [[ -f "$ZORIN_THEME_FILE.bak" ]]; then
-    echo "reverting '$ZORIN_THEME_FILE'..."
-    rm -rf "$ZORIN_THEME_FILE"
-    mv "$ZORIN_THEME_FILE.bak" "$ZORIN_THEME_FILE"
+    backup_file "${COMMON_CSS_FILE}"; backup_file "${TARGET}"
+
+    if check_exist "${GS_THEME_DIR}/${name}"; then
+      rm -rf "${GS_THEME_DIR}/${name}"
+    fi
+
+    cp -rf "${THEME_TEMP}/gnome-shell"                                                       "${GS_THEME_DIR}/${name}"
+    ln -sf "${GS_THEME_DIR}/${name}/gnome-shell.css"                                         "${COMMON_CSS_FILE}"
+    ln -sf "${GS_THEME_DIR}/${name}/gnome-shell.css"                                         "${TARGET}"
+
+    # Fix previously installed theme
+    restore_file "${ETC_CSS_FILE}"
+  else # GR-based theme
+    if check_exist "$POP_OS_GR_FILE"; then
+      TARGET="${POP_OS_GR_FILE}"
+    elif check_exist "$YARU_GR_FILE"; then
+      TARGET="${YARU_GR_FILE}"
+    elif check_exist "$ZORIN_GR_FILE"; then
+      TARGET="${ZORIN_GR_FILE}"
+    elif check_exist "$MISC_GR_FILE"; then
+      TARGET="${MISC_GR_FILE}"
+    fi
+
+    backup_file "${TARGET}"
+    glib-compile-resources --sourcedir="${THEME_TEMP}/gnome-shell" --target="${TARGET}" "${GS_GR_XML_FILE}"
+
+    # Fix previously installed theme
+    restore_file "${ETC_GR_FILE}"
   fi
 }
 
+uninstall_gdm_theme() {
+  rm -rf "${GS_THEME_DIR}/$THEME_NAME"
+  restore_file "${COMMON_CSS_FILE}"; restore_file "${UBUNTU_CSS_FILE}"
+  restore_file "${ZORIN_CSS_FILE}"; restore_file "${ETC_CSS_FILE}"
+  restore_file "${POP_OS_GR_FILE}"; restore_file "${YARU_GR_FILE}"
+  restore_file "${MISC_GR_FILE}"; restore_file "${ETC_GR_FILE}"
+  restore_file "${ZORIN_GR_FILE}"
+}
+
 while [[ $# -gt 0 ]]; do
   case "${1}" in
     -d|--dest)
       dest="${2}"
       if [[ ! -d "${dest}" ]]; then
-        echo "ERROR: Destination directory does not exist."
+        echo -e "ERROR: Destination directory does not exist."
         exit 1
       fi
       shift 2
@@ -337,16 +425,20 @@ while [[ $# -gt 0 ]]; do
       name="${2}"
       shift 2
       ;;
-    -l|--logo)
-      logo="${2}"
+    -i|--icon)
+      icon="${2}"
       shift 2
       ;;
     -g|--gdm)
       gdm='true'
       shift
       ;;
-    -r|--revert)
-      revert='true'
+    -l|--libadwaita)
+      libadwaita="true"
+      shift
+      ;;
+    -r|--remove|-u|--uninstall)
+      remove='true'
       shift
       ;;
     -t|--theme)
@@ -374,8 +466,8 @@ while [[ $# -gt 0 ]]; do
             break
             ;;
           *)
-            echo "ERROR: Unrecognized theme variant '$1'."
-            echo "Try '$0 --help' for more information."
+            echo -e "ERROR: Unrecognized theme variant '$1'."
+            echo -e "Try '$0 --help' for more information."
             exit 1
             ;;
         esac
@@ -387,22 +479,28 @@ while [[ $# -gt 0 ]]; do
         case "${color}" in
           standard)
             colors+=("${COLOR_VARIANTS[0]}")
-            shift 1
+            lcolors+=("${COLOR_VARIANTS[0]}")
+            gcolors+=("${COLOR_VARIANTS[0]}")
+            shift
             ;;
           light)
             colors+=("${COLOR_VARIANTS[1]}")
-            shift 1
+            lcolors+=("${COLOR_VARIANTS[1]}")
+            gcolors+=("${COLOR_VARIANTS[1]}")
+            shift
             ;;
           dark)
             colors+=("${COLOR_VARIANTS[2]}")
-            shift 1
+            lcolors+=("${COLOR_VARIANTS[2]}")
+            gcolors+=("${COLOR_VARIANTS[2]}")
+            shift
             ;;
           -*|--*)
             break
             ;;
           *)
-            echo "ERROR: Unrecognized color variant '$1'."
-            echo "Try '$0 --help' for more information."
+            echo -e "ERROR: Unrecognized color variant '$1'."
+            echo -e "Try '$0 --help' for more information."
             exit 1
             ;;
         esac
@@ -428,8 +526,8 @@ while [[ $# -gt 0 ]]; do
             break
             ;;
           *)
-            echo "ERROR: Unrecognized tweak variant '$1'."
-            echo "Try '$0 --help' for more information."
+            echo -e "ERROR: Unrecognized tweak variant '$1'."
+            echo -e "Try '$0 --help' for more information."
             exit 1
             ;;
         esac
@@ -440,8 +538,8 @@ while [[ $# -gt 0 ]]; do
       exit 0
       ;;
     *)
-      echo "ERROR: Unrecognized installation option '$1'."
-      echo "Try '$0 --help' for more information."
+      echo -e "ERROR: Unrecognized installation option '$1'."
+      echo -e "Try '$0 --help' for more information."
       exit 1
       ;;
   esac
@@ -452,7 +550,7 @@ function has_command() {
   command -v $1 > /dev/null
 }
 
-install_package() {
+install_css_deps() {
   if [ ! "$(which sassc 2> /dev/null)" ]; then
     echo "\n sassc needs to be installed to generate the css."
 
@@ -515,12 +613,24 @@ install_package() {
   fi
 }
 
-install_theme() {
-  for theme in "${themes[@]-${THEME_VARIANTS[0]}}"; do
-    for color in "${colors[@]-${COLOR_VARIANTS[@]}}"; do
-      install "${dest:-${DEST_DIR}}" "${name:-${THEME_NAME}}" "${theme}" "${color}" "${logo:-${LOGO_NAME}}"
-    done
-  done
+uninstall_link() {
+  rm -rf "${HOME}/.config/gtk-4.0"/{assets,gtk.css,gtk-dark.css}
+}
+
+link_libadwaita() {
+  local dest="${1}"
+  local name="${2}"
+  local theme="${3}"
+  local lcolor="${4}"
+
+  local THEME_DIR="${1}/${2}${3}${4}"
+
+  echo -e "\nLink '$THEME_DIR/gtk-4.0' to '${HOME}/.config/gtk-4.0' for libadwaita..."
+
+  mkdir -p                                                                      "${HOME}/.config/gtk-4.0"
+  ln -sf "${THEME_DIR}/gtk-4.0/assets"                                          "${HOME}/.config/gtk-4.0/assets"
+  ln -sf "${THEME_DIR}/gtk-4.0/gtk.css"                                         "${HOME}/.config/gtk-4.0/gtk.css"
+  ln -sf "${THEME_DIR}/gtk-4.0/gtk-dark.css"                                    "${HOME}/.config/gtk-4.0/gtk-dark.css"
 }
 
 tweaks_temp() {
@@ -545,10 +655,10 @@ install_round_window() {
 install_theme_color() {
   if [[ "$theme" != '' ]]; then
     case "$theme" in
-      -manjaro)
+      -Manjaro)
         theme_color='manjaro'
         ;;
-      -ubuntu)
+      -Ubuntu)
         theme_color='ubuntu'
         ;;
     esac
@@ -559,7 +669,7 @@ install_theme_color() {
 theme_tweaks() {
   if [[ "$image" == "true" || "$square" == "true" || "$accent" == 'true' || "$window" == 'round' ]]; then
     tweaks='true'
-    install_package; tweaks_temp
+    install_css_deps; tweaks_temp
   fi
 
   if [[ "$image" == "true" ]] ; then
@@ -575,17 +685,83 @@ theme_tweaks() {
   fi
 }
 
-if [[ "${gdm:-}" != 'true' && "${revert:-}" != 'true' ]]; then
+link_theme() {
+  for theme in "${themes[@]-${THEME_VARIANTS[0]}}"; do
+    for lcolor in "${lcolors[@]-${COLOR_VARIANTS[1]}}"; do
+      link_libadwaita "${dest:-$DEST_DIR}" "${name:-$THEME_NAME}" "$theme" "$lcolor"
+    done
+  done
+}
+
+install_theme() {
+  for theme in "${themes[@]-${THEME_VARIANTS[0]}}"; do
+    for color in "${colors[@]-${COLOR_VARIANTS[@]}}"; do
+      install "${dest:-$DEST_DIR}" "${name:-$THEME_NAME}" "${theme}" "${color}" "${icon:-${ICON_NAME}}"
+    done
+  done
+
+  for color in "${colors[@]-${COLOR_VARIANTS[@]}}"; do
+    for screen in '' '-hdpi' '-xhdpi'; do
+      install_xfwm "${dest:-$DEST_DIR}" "${name:-$THEME_NAME}" "${color}" "${screen}"
+    done
+  done
+}
+
+uninstall_theme() {
+  for theme in "${themes[@]-${THEME_VARIANTS[@]}}"; do
+    for color in "${colors[@]-${COLOR_VARIANTS[@]}}"; do
+      for screen in '' '-hdpi' '-xhdpi'; do
+        uninstall "${dest:-$DEST_DIR}" "${name:-$THEME_NAME}" "${theme}" "${color}" "${screen}"
+      done
+    done
+  done
+}
+
+./clean-old-theme.sh
+
+if [[ "${gdm:-}" != 'true' && "${remove:-}" != 'true' ]]; then
   install_theme
+
+   if [[ "$libadwaita" == 'true' ]]; then
+     uninstall_link && link_theme
+   fi
 fi
 
-if [[ "${gdm:-}" == 'true' && "${revert:-}" != 'true' && "$UID" -eq "$ROOT_UID" ]]; then
-  install_theme && install_gdm "${dest:-${DEST_DIR}}" "${name:-${THEME_NAME}}" "${theme}" "${color}"
+if [[ "${gdm:-}" != 'true' && "${remove:-}" == 'true' ]]; then
+  if [[ "$libadwaita" == 'true' ]]; then
+    echo -e "\nUninstall ${HOME}/.config/gtk-4.0 links ..."
+    uninstall_link
+  else
+    echo && uninstall_theme && uninstall_link
+  fi
 fi
 
-if [[ "${gdm:-}" != 'true' && "${revert:-}" == 'true' && "$UID" -eq "$ROOT_UID" ]]; then
-  revert_gdm
+if [[ "${gdm:-}" == 'true' && "${remove:-}" != 'true' && "$UID" -eq "$ROOT_UID" ]]; then
+  if [[ "${#gcolors[@]}" -gt 1 ]]; then
+    echo -e 'Error: To install a gdm theme you can only select one color'
+    exit 1
+  fi
+  if [[ "${#themes[@]}" -gt 1 ]]; then
+    echo -e 'Error: To install a gdm theme you can only select one theme'
+    exit 1
+  fi
+
+  echo -e "\nNOTICE: Only GDM theme will installed..."
+
+  for theme in "${themes[@]-${THEME_VARIANTS[0]}}"; do
+    for gcolor in "${gcolors[@]-${COLOR_VARIANTS[2]}}"; do
+      install_gdm "${name:-${THEME_NAME}}" "${theme}" "${gcolor}" "${icon:-${ICON_NAME}}"
+    done
+  done
 fi
 
-echo
-echo Done.
+if [[ "${gdm:-}" == 'true' && "${remove:-}" == 'true' && "$UID" -eq "$ROOT_UID" ]]; then
+  uninstall_gdm_theme
+fi
+
+if [[ "${gdm:-}" == 'true' && "$UID" != "$ROOT_UID" ]]; then
+  echo -e 'Error: need run it with sudo !'
+  exit 0
+fi
+
+echo -e "\nDone.\n"
